@@ -485,7 +485,7 @@ def characterizePartitionErrors(sequences, clones, meta_data):
     nseqs = len(sequences)
     imgtar = clones[0].getField("imgtpartlabels")
     germline = clones[0].getField("germline_imgt_d_mask")
-    if germline is "":
+    if germline == "":
         germline = clones[0].getField("germline_imgt")
 
     correctseqs = False
@@ -540,7 +540,7 @@ def characterizePartitionErrors(sequences, clones, meta_data):
     resolveglines = False
     for c in clones:
         ngermline = c.getField("germline_imgt_d_mask")
-        if ngermline is "":
+        if ngermline == "":
             ngermline = c.getField("germline_imgt")
         if ngermline != germline:
             resolveglines = True
@@ -798,7 +798,7 @@ def maskCodonsLoop(r, clones, cloneseqs, logs, fails, out_args, fail_writer, mas
         #If IMGT regions are provided, record their positions
         rd = RegionDefinition(r.junction_length, amino_acid=False)
         regions = rd.getRegions(r.sequence_imgt)
-        if regions["cdr3_imgt"] is not "" and regions["cdr3_imgt"] is not None:
+        if regions["cdr3_imgt"] != "" and regions["cdr3_imgt"] is not None:
             simgt = regions["fwr1_imgt"] + regions["cdr1_imgt"] + regions["fwr2_imgt"] + regions["cdr2_imgt"] + \
                     regions["fwr3_imgt"] + regions["cdr3_imgt"] + regions["fwr4_imgt"]
             if len(simgt) < len(r.sequence_imgt):
@@ -824,7 +824,7 @@ def maskCodonsLoop(r, clones, cloneseqs, logs, fails, out_args, fail_writer, mas
                 fails["region_fail"] += 1
                 return 0
 
-        elif regions["fwr3_imgt"] is not "" and regions["fwr3_imgt"] is not None:
+        elif regions["fwr3_imgt"] != "" and regions["fwr3_imgt"] is not None:
             simgt = regions["fwr1_imgt"] + regions["cdr1_imgt"] + regions["fwr2_imgt"] + regions["cdr2_imgt"] + \
                     regions["fwr3_imgt"]
             nseq = r.sequence_imgt[len(simgt):len(r.sequence_imgt)]
