@@ -943,7 +943,8 @@ class IgBLASTReader:
                        'stop codon': 'stop_codon',
                        'V-J frame': 'vj_frame',
                        'Productive': 'productive',
-                       'Strand': 'strand'}
+                       'Strand': 'strand',
+                       'V Frame shift': 'v_frameshift'}
 
         # Extract column names from comments
         f = next((x for x in chunk if x.startswith('# V-(D)-J rearrangement summary')))
@@ -1063,6 +1064,10 @@ class IgBLASTReader:
         else:
             result['rev_comp'] = 'F'
 
+        # Add v_frameshift field if present
+        if 'v_frameshift' in summary:
+            result['v_frameshift'] = 'T' if summary['v_frameshift'] == 'Yes' else 'F'
+
         return result
 
     def _parseSubregionSection(self, section, sequence):
@@ -2444,7 +2449,8 @@ def checkFields(attributes, header, schema=AIRRSchema):
     Raises:
         LookupError:
     """
-    columns = [schema.fromReceptor(f) for f in attributes]
+    if schema is None:  columns = attributes
+    else:  columns = [schema.fromReceptor(f) for f in attributes]
     missing = [x for x in columns if x not in header]
 
     if len(missing) > 0:
